==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/e3/e3dbc68a48c5392b280a680c7aab7f23.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php */
class __TwigTemplate_8e57e92779f650e68481d4679589caf9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\DAO\\Value;

class ReferenceValueDAO implements \\Stringable
{
    private ?int \$value = null;

    private ?string \$type = null;

    public function getValue(): ?int
    {
        return \$this->value;
    }

    public function setValue(int \$value): void
    {
        \$this->value = \$value;
    }

    public function getType(): ?string
    {
        return \$this->type;
    }

    public function setType(string \$type): void
    {
        \$this->type = \$type;
    }

    public function __toString(): string
    {
        return (string) \$this->value;
    }

    /** @return array<string, mixed> */
    public function __serialize(): array
    {
        return [
            'value' => \$this->value,
            'types' => \$this->type,
        ];
    }

    /** @param array<string, mixed> \$data */
    public function __unserialize(array \$data): void
    {
        \$this->value = \$data['value'] ?? null;
        \$this->type  = \$data['type'] ?? null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/e3/e3dbc68a48c5392b280a680c7aab7f23.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php */
class __TwigTemplate_8e57e92779f650e68481d4679589caf9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\DAO\\Value;

class ReferenceValueDAO implements \\Stringable
{
    private ?int \$value = null;

    private ?string \$type = null;

    public function getValue(): ?int
    {
        return \$this->value;
    }

    public function setValue(int \$value): void
    {
        \$this->value = \$value;
    }

    public function getType(): ?string
    {
        return \$this->type;
    }

    public function setType(string \$type): void
    {
        \$this->type = \$type;
    }

    public function __toString(): string
    {
        return (string) \$this->value;
    }

    /** @return array<string, mixed> */
    public function __serialize(): array
    {
        return [
            'value' => \$this->value,
            'types' => \$this->type,
        ];
    }

    /** @param array<string, mixed> \$data */
    public function __unserialize(array \$data): void
    {
        \$this->value = \$data['value'] ?? null;
        \$this->type  = \$data['type'] ?? null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php", "/var/www/html/production-demo/app/bundles/IntegrationsBundle/Sync/DAO/Value/ReferenceValueDAO.php");
    }
}
